@@ -35,7 +35,7 @@ from displayconfigabstraction import *
 from execwithcapture import *
 
 programname = "Display and Graphics Configuration"
-version = "0.7.0"
+version = "0.7.1"
 DUAL_PREVIEW_SIZE = 240
 
 # Are we running as a separate standalone application or in KControl?
@@ -498,7 +498,7 @@ class DisplayApp(programbase):
         global standalone
         if not standalone:
             toplayout = QVBoxLayout( self, 0, KDialog.spacingHint() )
-            tabcontrol = KTabCtl(self)
+            tabcontrol = QTabWidget(self)
             toplayout.addWidget(tabcontrol)
             toplayout.setStretchFactor(tabcontrol,1)
 
@@ -1002,15 +1002,17 @@ class DisplayApp(programbase):
             self.gammaradiogroup.setButton(0)
         else:
             self.gammaradiogroup.setButton(1)
+        
         self.gammaslider.setValue(self.currentgammascreen.getAllGamma())
         self.redslider.setValue(self.currentgammascreen.getRedGamma())
         self.greenslider.setValue(self.currentgammascreen.getGreenGamma())
         self.blueslider.setValue(self.currentgammascreen.getBlueGamma())
 
-        self.gammaslider.setDisabled(not self.currentgammascreen.isGammaEqual())
-        self.redslider.setDisabled(self.currentgammascreen.isGammaEqual())
-        self.greenslider.setDisabled(self.currentgammascreen.isGammaEqual())
-        self.blueslider.setDisabled(self.currentgammascreen.isGammaEqual())
+        self.settingall = self.currentgammascreen.isGammaEqual()
+        self.gammaslider.setDisabled(not self.settingall)
+        self.redslider.setDisabled(self.settingall)
+        self.greenslider.setDisabled(self.settingall)
+        self.blueslider.setDisabled(self.settingall)
         self._syncTestButton()
 
     def _syncTestButton(self):
@@ -1023,9 +1025,9 @@ class DisplayApp(programbase):
 
     def _loadConfig(self):
         self.config.setGroup("General")
-        t = self.config.readEntry("targetgamma","2.0")
+        t = self.config.readEntry("targetgamma",unicode(i18n("2.0")))
         if t in self.availabletargetgammas:
-            t = '2.0'
+            t = unicode(i18n('2.0'))
         self.targetgamma = self.availabletargetgammas.index(t)
 
     def _saveConfig(self):
@@ -1035,19 +1037,30 @@ class DisplayApp(programbase):
         self.config.setGroup("General")
         self.config.writeEntry("targetgamma",self.availabletargetgammas[self.targetgamma])
         for s in self.xsetup.getUsedScreens():
+            self.config.setGroup("Screen"+str(s.getScreenIndex()))
             self._saveRandRConfig(s)
+            
+            # Write out the gamma values.
+            if self.settingall:
+                self.config.writeEntry("redgamma", str(s.getAllGamma()))
+                self.config.writeEntry("greengamma", str(s.getAllGamma()))
+                self.config.writeEntry("bluegamma", str(s.getAllGamma()))
+            else:
+                self.config.writeEntry("redgamma", str(s.getRedGamma()))
+                self.config.writeEntry("greengamma", str(s.getGreenGamma()))
+                self.config.writeEntry("bluegamma", str(s.getBlueGamma()))
+            
+        self.config.writeEntry("dpmsSeconds", self.dpmspage.seconds)
+        self.config.writeEntry("dpmsEnabled", ("off","on")[self.dpmspage.enabled])
         self.config.sync()
 
     def _saveRandRConfig(self,screen):
         w,h = screen.getAvailableResolutions()[screen.getResolutionIndex()]
-        self.config.setGroup("Screen"+str(screen.getScreenIndex()))
         self.config.writeEntry("width",w)
         self.config.writeEntry("height",h)
         self.config.writeEntry("reflectX", int( (screen.getReflection() & screen.RR_Reflect_X)!=0) )
         self.config.writeEntry("reflectY", int((screen.getReflection() & screen.RR_Reflect_Y)!=0) )
         self.config.writeEntry("refresh", screen.getAvailableRefreshRates()[screen.getRefreshRateIndex()])
-        self.config.writeEntry("dpmsSeconds", self.dpmspage.seconds)
-        self.config.writeEntry("dpmsEnabled", ("off","on")[self.dpmspage.enabled])
         rotationmap = {screen.RR_Rotate_0: "0", screen.RR_Rotate_90: "90",
                         screen.RR_Rotate_180:"180", screen.RR_Rotate_270: "270"}
         self.config.writeEntry("rotate", rotationmap[screen.getRotation()])
@@ -1611,7 +1624,7 @@ class DpmsPage(QWidget):
                 self.dpms_min = int(line.strip().split()[5]) # TODO: More subtle exception handling. ;)
             if line.strip().startswith("DPMS is"):
                 self.dpms_enabled = line.strip().split()[2]=="Enabled"
-        
+
         if self.dpms_min==0:    # 0 also means don't use Standby mode.
             self.dpms_enabled = False
             self.dpms_min = 1800
@@ -1688,7 +1701,7 @@ def create_displayconfig(parent,name):
 def MakeAboutData():
     aboutdata = KAboutData("guidance",programname,version, \
         "Display and Graphics Configuration Tool", KAboutData.License_GPL, \
-        "Copyright (C) 2003-2006 Simon Edwards", \
+        "Copyright (C) 2003-2007 Simon Edwards", \
         "Thanks go to  Phil Thompson, Jim Bublitz and David Boddie.")
     aboutdata.addAuthor("Simon Edwards","Developer","simon@simonzone.com", \
             "http://www.simonzone.com/software/")
