@@ -29,7 +29,7 @@ class SMBShareSelectDialog(KDialogBase):
     
     ########################################################################
     def __init__(self,parent,name=None):
-        super(SMBShareSelectDialog,self).__init__(parent,name,1,None,KDialogBase.Ok|KDialogBase.Cancel)
+        super(SMBShareSelectDialog,self).__init__(parent,name,1,"",KDialogBase.Ok|KDialogBase.Cancel)
         self.updatinggui = False
         
         self.resize(600,400)
@@ -44,14 +44,14 @@ class SMBShareSelectDialog(KDialogBase):
         hbox.setStretchFactor(tmplabel,0)
 
         self.headinglabel = QLabel(hbox)
-        self.headinglabel.setText("Select a network share")
+        self.headinglabel.setText(i18n("Select a network share"))
         hbox.setStretchFactor(self.headinglabel,1)
 
         hbox2 = QHBox(vbox)
         
         # The main treeview where the action happens.
         self.treeview = KListView(hbox2)
-        self.treeview.addColumn("Foobar")
+        self.treeview.addColumn("(hidden)")
         self.treeview.header().hide()
         self.treeview.setRootIsDecorated(True)
         
@@ -65,6 +65,7 @@ class SMBShareSelectDialog(KDialogBase):
         self.connect(self.dirlister,SIGNAL("newItems(const KFileItemList &)"),self.slotNewItems)
         self.connect(self.dirlister,SIGNAL("completed()"),self.slotDirListCompleted)
         self.connect(self.dirlister,SIGNAL("canceled()"),self.slotDirListCanceled)
+        self.connect(self.dirlister,SIGNAL("redirection(const KURL &,const KURL &)"),self.slotDirListRedirection)
         self.enableButtonOK(False)
 
         # The "Connect as" part
@@ -84,14 +85,14 @@ class SMBShareSelectDialog(KDialogBase):
         self.guestradio.setChecked(True)
         grid.addWidget(self.guestradio,1,1)
         tmplabel = QLabel(widget)
-        tmplabel.setText("Guest")
+        tmplabel.setText(i18n("Guest"))
         grid.addWidget(tmplabel,1,2)
         self.connect(self.guestradio,SIGNAL("stateChanged(int)"),self.slotGuestRadioClicked)
         
         self.userradio = QRadioButton(widget)
         grid.addWidget(self.userradio,2,1)
         tmplabel = QLabel(widget)
-        tmplabel.setText("Username:")
+        tmplabel.setText(i18n("Username:"))
         grid.addWidget(tmplabel,2,2)
         self.connect(self.userradio,SIGNAL("stateChanged(int)"),self.slotUserRadioClicked)
         
@@ -100,14 +101,13 @@ class SMBShareSelectDialog(KDialogBase):
         self.connect(self.usernameedit,SIGNAL("textChanged(const QString &)"),self.slotUsernameChanged)
         
         tmplabel = QLabel(widget)
-        tmplabel.setText("Password:")
+        tmplabel.setText(i18n("Password:"))
         grid.addWidget(tmplabel,3,2)
         
         self.passwordedit = KLineEdit(widget)
         grid.addWidget(self.passwordedit,3,3)
-        self.connect(self.passwordedit,SIGNAL("textChanged(const QString &)"),self.slotPasswordChanged)
         
-        self.reconnectbutton = KPushButton("Reconnect now",widget)
+        self.reconnectbutton = KPushButton(i18n("Reconnect now"),widget)
         grid.addMultiCellWidget(self.reconnectbutton,4,4,1,3)
         self.connect(self.reconnectbutton,SIGNAL("clicked()"),self.slotReconnectClicked)
         
@@ -119,8 +119,11 @@ class SMBShareSelectDialog(KDialogBase):
         self.selecteditem = None
 
         self.treeview.clear()
+        self.url_to_list_item_map = {}
+        
         # Fill the first level
-        self.rootitem = SMBShareListViewItem(self.treeview,"Network Neighbourhood",KURL("smb:/"),self)
+        root_url = KURL("smb:/")
+        self.rootitem = SMBShareListViewItem(self.treeview, i18n("Network Neighbourhood"), root_url, self)
 
         self.searchurl = currenturl
         self._updateConnectGUI()
@@ -129,15 +132,16 @@ class SMBShareSelectDialog(KDialogBase):
         
         self.spintimerid = self.startTimer(250)
         self.exec_loop()
-
         self.stopResolve()
         
         self.killTimer(self.spintimerid)
 
         if self.result()==self.Accepted:
-            return self.selecteditem.getURL()
-        else:
-            return currenturl
+            currenturl = self.selecteditem.getURL()
+
+        self.url_to_list_item_map = None
+        
+        return currenturl
 
     ########################################################################
     def _openDefaultURL(self):
@@ -194,11 +198,14 @@ class SMBShareSelectDialog(KDialogBase):
         self._updateConnectGUI()
         self.enableButtonOK(item.getLevel()==item.LEVEL_DIR)
         
+        if not self.selecteditem.isResolved():
+            self.selecteditem.startResolve(False)
+
     ########################################################################
     def slotNewItems(self,items):
         for entry in items:
-            print entry.name()
-            newitem = SMBShareListViewItem(self.lookupqueue[0],str(entry.name()),KURL(entry.url()),self)
+            newitem = SMBShareListViewItem(self.lookupqueue[0], unicode(entry.name()), KURL(entry.url()), self)
+            self.url_to_list_item_map[unicode(entry.url().prettyURL())] = newitem
             # Notice how I copied the KURL object and QString (to a python string)
         
     ########################################################################
@@ -215,14 +222,21 @@ class SMBShareSelectDialog(KDialogBase):
     ########################################################################
     def slotDirListCanceled(self):
         self.stopResolve()
+        
+    ########################################################################
+    def slotDirListRedirection(self,oldUrl,newUrl):
+        list_item = self.url_to_list_item_map[unicode(oldUrl.prettyURL())]
+        list_item.setURL(KURL(newUrl)) # The copy is important.
+        
+        # Reselect the selected node. (This will force a refresh).
+        if self.selecteditem is not None:
+            self.updatinggui = True
+            self.slotNodeSelected(self.selecteditem)
+            self.updatinggui = False
 
-    ########################################################################
-    def slotPasswordChanged(self,newtext):
-        self.reconnectbutton.setEnabled(self.usernameedit.text()!="" and self.passwordedit.text()!="")
-            
     ########################################################################
     def slotUsernameChanged(self,newtext):
-        self.reconnectbutton.setEnabled(self.usernameedit.text()!="" and self.passwordedit.text()!="")
+        self.reconnectbutton.setEnabled(self.usernameedit.text()!="")
 
     ########################################################################
     def slotReconnectClicked(self):
@@ -249,10 +263,10 @@ class SMBShareSelectDialog(KDialogBase):
         
         # Set the username/password for the machine item.
         if self.guestradio.isChecked():
-            machineitem.getURL().setUser(None)
-            machineitem.getURL().setPass(None)
-            selectedurl.setUser(None)
-            selectedurl.setPass(None)
+            machineitem.getURL().setUser(QString.null)
+            machineitem.getURL().setPass(QString.null)
+            selectedurl.setUser(QString.null)
+            selectedurl.setPass(QString.null)
         else:
             machineitem.getURL().setUser(self.usernameedit.text())
             machineitem.getURL().setPass(self.passwordedit.text())
@@ -292,6 +306,9 @@ class SMBShareSelectDialog(KDialogBase):
             return
         self.updatinggui = True
         
+        if self.selecteditem is None:
+            return
+            
         if state==QButton.Off:
             self.guestradio.setChecked(True)
         self.userradio.setChecked(False)
@@ -300,7 +317,7 @@ class SMBShareSelectDialog(KDialogBase):
         self.usernameedit.setEnabled(False)
 
         selectedurl = self.selecteditem.getURL()
-        self.reconnectbutton.setEnabled(str(selectedurl.user())!="")
+        self.reconnectbutton.setEnabled(unicode(selectedurl.user())!="")
         
         self.updatinggui = False
         
@@ -316,11 +333,11 @@ class SMBShareSelectDialog(KDialogBase):
         self.passwordedit.setEnabled(True)
         self.usernameedit.setEnabled(True)
         
-        username = str(self.usernameedit.text())
-        password = str(self.passwordedit.text())
+        username = unicode(self.usernameedit.text())
+        password = unicode(self.passwordedit.text())
         selectedurl = self.selecteditem.getURL()
         if username!="" and password!="" and \
-                ((str(selectedurl.user())!=username) or (str(selectedurl.pass_())!=password)):
+                ((unicode(selectedurl.user())!=username) or (unicode(selectedurl.pass_())!=password)):
             self.reconnectbutton.setEnabled(True)
         else:
             self.reconnectbutton.setEnabled(False)
@@ -335,13 +352,12 @@ class SMBShareSelectDialog(KDialogBase):
             self.userradio.setEnabled(True)
             self.usernameedit.setEnabled(selectedurl.hasUser())
             self.passwordedit.setEnabled(selectedurl.hasUser())
-            self.connectaslabel.setText("Connect to '%s' as:" % selectedurl.host())
+            self.connectaslabel.setText(i18n("Connect to '%1' as:").arg(selectedurl.host()))
             if selectedurl.hasUser():
                 self.guestradio.setChecked(False)
                 self.userradio.setChecked(True)
                 self.usernameedit.setText(selectedurl.user())
                 self.passwordedit.setText(selectedurl.pass_())
-                #self.reconnectbutton.setEnabled(on)
             else:
                 self.guestradio.setChecked(True)
                 self.userradio.setChecked(False)
@@ -355,7 +371,7 @@ class SMBShareSelectDialog(KDialogBase):
             self.userradio.setEnabled(False)
             self.passwordedit.setEnabled(False)
             self.usernameedit.setEnabled(False)
-            self.connectaslabel.setText("Connect to 'machine' as:")
+            self.connectaslabel.setText(i18n("Connect to 'machine' as:"))
             self.guestradio.setChecked(True)
             self.userradio.setChecked(False)
             self.passwordedit.setText("")
@@ -388,10 +404,10 @@ class SMBShareListViewItem(KListViewItem):
         self.setExpandable(True)
         
         if url.hasPath() and url.path(-1)!="/":
-            parts = [x for x in str(url.path(-1)).split("/") if x!=""]
+            parts = [x for x in unicode(url.path(-1)).split("/") if x!=""]
             self.component = parts[-1].lower()
         elif url.hasHost():
-            self.component = str(url.host()).lower()
+            self.component = unicode(url.host()).lower()
         else:
             self.component = None
         
@@ -404,6 +420,10 @@ class SMBShareListViewItem(KListViewItem):
     ########################################################################
     def getURL(self):
         return self.url
+        
+    ########################################################################
+    def setURL(self,url):
+        self.url = url
 
     ########################################################################
     def getComponent(self):
@@ -482,13 +502,12 @@ class SMBShareListViewItem(KListViewItem):
     # Another wrinkle is that the treeview contains a level of workgroups while
     # a given URL omits the workgroup a jumps directly to the machine name.
     def selectURL(self,targeturl):
-        path = str(targeturl.path(-1))
+        path = unicode(targeturl.path(-1))
         parts = [x for x in path.split("/") if x!=""]
         if targeturl.hasHost():
             tmp = [targeturl.host()]
             tmp.extend(parts)
             parts = tmp
-        print parts
         
         if self.getLevel()==self.LEVEL_ROOT:
             # Root item.
