@@ -17,10 +17,12 @@ import random
 import fcntl
 import time
 import os
+import os.path
 import stat
 import shutil
 import codecs
 import locale
+import tempfile
 
 ldaperror = ""
 try:
@@ -28,6 +30,20 @@ try:
 except ImportError:
     ldaperror = "The LDAP Python Module is not installed, but needed to use LDAP. Install it."
 
+def createTempFile(origfile):
+    origstat = os.stat(origfile)
+    tmp_prefix = os.path.basename(origfile) + "."
+    tmp_dir = os.path.dirname(origfile)
+    try:
+        ret = tempfile.mkstemp(prefix=tmp_prefix, dir=tmp_dir)
+    except:
+        raise IOError, "Unable to create a new temporary file for " + origfile
+    (fd, tmpfile) = ret
+    shutil.copymode(origfile, tmpfile)
+    os.chown(tmpfile, origstat.st_uid, origstat.st_gid)
+
+    return ret
+
 def getContext(editmode=False):
     """Get a Context object describing the system's authorisation database.
 
@@ -479,14 +495,14 @@ class UnixUser(object):
             # The GID didn't match an existing group. Quickly make a new group.
             new_group = self._context.newGroup()
             new_group.setGID(self._gid)
-            
+
             new_group_name = u"group%i" % self._gid
             i = 0
             while self._context.lookupGroupname(new_group_name) is not None:
                 i += 1
                 new_group_name = u"group%i_%i" % (self._gid,i)
             new_group.setGroupname(new_group_name)
-            
+
             self._context.addGroup(new_group)
             primary_group = new_group
 
@@ -694,7 +710,7 @@ class UnixGroup(object):
 
 ###########################################################################
 class PwdContext(Context):
-#    def __init__(self,editmode,passwordfile="/home/sbe/etc/passwd",groupfile='/home/sbe/etc/group',shadowfile="/home/sbe/etc/shadow"):
+    #def __init__(self,editmode,passwordfile="etc-passwd",groupfile='etc-group',shadowfile="etc-shadow"):
     def __init__(self,editmode,passwordfile="/etc/passwd",groupfile='/etc/group',shadowfile="/etc/shadow"):
         Context.__init__(self)
         self.__editmode = editmode
@@ -758,7 +774,7 @@ class PwdContext(Context):
                                     userobj._passlastchange = int(passlastchange)
                                 else:
                                     passlastchange = 0
-    
+
                                 if passminimumagebeforechange=="":
                                     passminimumagebeforechange = None
                                 else:
@@ -766,7 +782,7 @@ class PwdContext(Context):
                                     if passminimumagebeforechange>=99999:
                                         passminimumagebeforechange = None
                                 userobj._passminimumagebeforechange = passminimumagebeforechange
-    
+
                                 if passmaximumage=="":
                                     passmaximumage = None
                                 else:
@@ -774,7 +790,7 @@ class PwdContext(Context):
                                     if passmaximumage>=99999:
                                         passmaximumage = None
                                 userobj._passmaximumage = passmaximumage
-    
+
                                 if passexpirewarn=="":
                                     passexpirewarn = None
                                 else:
@@ -782,17 +798,17 @@ class PwdContext(Context):
                                     if passexpirewarn>=99999:
                                         passexpirewarn = None
                                 userobj._passexpirewarn = passexpirewarn
-    
+
                                 if passexpiredisabledays=="":
                                     userobj._passexpiredisabledays = None
                                 else:
                                     userobj._passexpiredisabledays = int(passexpiredisabledays)
-    
+
                                 if disableddays=="" or disableddays==u"99999":
                                     userobj._disableddays = None
                                 else:
                                     userobj._disableddays = int(disableddays)
-    
+
                                 userobj._reserve = reserve
                             else:
                                 print "Couldn't find",username
@@ -820,29 +836,25 @@ class PwdContext(Context):
         self._sanityCheck()
 
         # Write out the new password file.        
-        origstat = os.stat(self.__passwordfile)
-        tmpname = self.__passwordfile+".TMP"
-        fd = os.open(tmpname, os.O_CREAT|os.O_WRONLY|os.O_TRUNC, origstat.st_mode)
+        (fd, tmpname) = createTempFile(self.__passwordfile)
         for u in self._users:
             os.write(fd, u._getPasswdEntry().encode(locale.getpreferredencoding(),'replace'))
             #print u._getPasswdEntry()
         os.close(fd)
-        os.chown(tmpname, origstat.st_uid, origstat.st_gid)
-        
+
         # Update the passwd file
         passwordlock = os.open(self.__passwordfile, os.O_WRONLY) # FIXME encoding
         if LockFDWrite(passwordlock)==False:
             raise IOError,"Couldn't get a write lock on "+self.__passwordfile
         try:
-            os.rename(self.__passwordfile+".TMP",self.__passwordfile)
+            os.rename(tmpname, self.__passwordfile)
         finally:
             UnlockFD(passwordlock)
             os.close(passwordlock)
 
         # Write out the new group file
+        (fd, tmpname) = createTempFile(self.__groupfile)
         origstat = os.stat(self.__groupfile)
-        tmpname = self.__groupfile+".TMP"
-        fd = os.open(tmpname, os.O_CREAT|os.O_WRONLY|os.O_TRUNC, origstat.st_mode)
         for g in self._groups:
             os.write(fd,g._getGroupFileEntry().encode(locale.getpreferredencoding()))
             #print g._getGroupFileEntry()[:-1]
@@ -854,20 +866,18 @@ class PwdContext(Context):
         if LockFDWrite(grouplock)==False:
             raise IOError,"Couldn't get write lock on "+self.__groupfile
         try:
-            os.rename(self.__groupfile+".TMP",self.__groupfile)
+            os.rename(tmpname, self.__groupfile)
         finally:
             UnlockFD(grouplock)
             os.close(grouplock)
 
         # Write out the new shadow file
         origstat = os.stat(self.__shadowfile)
-        tmpname = self.__shadowfile+".TMP"
-        fd = os.open(tmpname, os.O_CREAT|os.O_WRONLY|os.O_TRUNC, origstat.st_mode|stat.S_IWUSR)
+        (fd, tmpname) = createTempFile(self.__shadowfile)
         for u in self._users:
             os.write(fd,u._getShadowEntry().encode(locale.getpreferredencoding()))
             #print u._getShadowEntry()[:-1]
         os.close(fd)
-        os.chown(tmpname, origstat.st_uid, origstat.st_gid)
 
         # Update the shadow file.
 
@@ -879,7 +889,7 @@ class PwdContext(Context):
         if LockFDWrite(shadowlock)==False:
             raise IOError,"Couldn't get write lock on "+self.__shadowfile
         try:
-            os.rename(self.__shadowfile+".TMP",self.__shadowfile)
+            os.rename(tmpname, self.__shadowfile)
         finally:
             UnlockFD(shadowlock)
             os.close(shadowlock)
@@ -890,7 +900,7 @@ class PwdContext(Context):
 
 ###########################################################################
 class LdapContext(Context):
-    
+
     def __init__(self,editmode,server="localhost",admin_dn="",admin_pass=""):
         """ Connect to the LDAP server and invoke further actions. 
         """
@@ -966,13 +976,13 @@ class LdapContext(Context):
                 new_user.setUsername(login)
                 _users.append(new_user)
                 print "Number of Users:", len(self._users)
-                
+
             except KeyError, e:
                 # Debugging output...
                 print "ERR:: ",e
                 print 'err:: ',entry
         return _users
-        
+
     def _createUser(self):
         return LdapUser(self)
 
@@ -984,14 +994,14 @@ class LdapContext(Context):
 
 ###########################################################################
 class LdapUser(UnixUser):
-    
+
     def __str__(self):
         return "LdapUser: %s(%i)" % (self._username,self._uid)
 
 
 ###########################################################################
 class LdapGroup(UnixGroup):
-    
+
     def __str__(self):
         return "LdapGroup: %s(%i)" % (self._username,self._uid)
 
